@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Moose::Meta::Attribute;
-our $VERSION = '2.1605';
+our $VERSION = '2.1804';
 
 use B ();
 use Scalar::Util 'blessed';
@@ -324,21 +324,12 @@ sub _process_isa_option {
 
     # allow for anon-subtypes here ...
     #
-    # Checking for Specio explicitly is completely revolting. At some point
-    # this needs to be refactored so that Moose core defines a standard type
-    # API that all types must implement. Unfortunately, the current core API
-    # is _not_ the right API, so we probably need to A) come up with the new
-    # API (Specio is a good start); B) refactor the core types to implement
-    # that API; C) do duck type checking on type objects.
+    # There are a _lot_ of methods that we expect from TC objects, but
+    # checking for a specific parent class via ->isa is gross, so we'll check
+    # for at least one method.
     if ( blessed( $options->{isa} )
-        && $options->{isa}->isa('Moose::Meta::TypeConstraint') ) {
-        $options->{type_constraint} = $options->{isa};
-    }
-    elsif (
-        blessed( $options->{isa} )
-        && $options->{isa}->can('does')
-        && $options->{isa}->does('Specio::Constraint::Role::Interface')
-        ) {
+        && $options->{isa}->can('has_coercion') ) {
+
         $options->{type_constraint} = $options->{isa};
     }
     else {
@@ -357,7 +348,8 @@ sub _process_does_option {
 
     # allow for anon-subtypes here ...
     if ( blessed( $options->{does} )
-        && $options->{does}->isa('Moose::Meta::TypeConstraint') ) {
+        && $options->{does}->can('has_coercion') ) {
+
         $options->{type_constraint} = $options->{does};
     }
     else {
@@ -1292,7 +1284,7 @@ Moose::Meta::Attribute - The Moose attribute metaclass
 
 =head1 VERSION
 
-version 2.1605
+version 2.1804
 
 =head1 DESCRIPTION
 
